package java.io;

import java.util.Vector;

public class File implements Serializable {
   private String path;
   public static final String separator = System.getProperty("file.separator");
   public static final char separatorChar;
   public static final String pathSeparator;
   public static final char pathSeparatorChar;
   private static final long serialVersionUID = 301077366599181567L;

   public File(String var1) {
      if (var1 == null) {
         throw new NullPointerException();
      } else {
         this.path = var1;
      }
   }

   public File(String var1, String var2) {
      if (var2 == null) {
         throw new NullPointerException();
      } else if (var1 != null) {
         if (var1.endsWith(separator)) {
            this.path = var1 + var2;
         } else {
            this.path = var1 + separator + var2;
         }
      } else {
         this.path = var2;
      }
   }

   public File(File var1, String var2) {
      this(var1.getPath(), var2);
   }

   public String getName() {
      int var1 = this.path.lastIndexOf(separatorChar);
      return var1 < 0 ? this.path : this.path.substring(var1 + 1);
   }

   public String getPath() {
      return this.path;
   }

   public String getAbsolutePath() {
      return this.isAbsolute() ? this.path : System.getProperty("user.dir") + separator + this.path;
   }

   public String getCanonicalPath() throws IOException {
      System.getSecurityManager().checkRead(this.path);
      return this.isAbsolute() ? this.canonPath(this.path) : this.canonPath(System.getProperty("user.dir") + separator + this.path);
   }

   public String getParent() {
      int var1 = this.path.lastIndexOf(separatorChar);
      if (var1 < 0) {
         return null;
      } else if (this.isAbsolute() && this.path.indexOf(separatorChar) == var1) {
         return var1 < this.path.length() - 1 ? this.path.substring(0, var1 + 1) : null;
      } else {
         return this.path.substring(0, var1);
      }
   }

   private native boolean exists0();

   private native boolean canWrite0();

   private native boolean canRead0();

   private native boolean isFile0();

   private native boolean isDirectory0();

   private native long lastModified0();

   private native long length0();

   private native boolean mkdir0();

   private native boolean renameTo0(File var1);

   private native boolean delete0();

   private native boolean rmdir0();

   private native String[] list0();

   private native String canonPath(String var1) throws IOException;

   public boolean exists() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkRead(this.path);
      }

      return this.exists0();
   }

   public boolean canWrite() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkWrite(this.path);
      }

      return this.canWrite0();
   }

   public boolean canRead() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkRead(this.path);
      }

      return this.canRead0();
   }

   public boolean isFile() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkRead(this.path);
      }

      return this.isFile0();
   }

   public boolean isDirectory() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkRead(this.path);
      }

      return this.isDirectory0();
   }

   public native boolean isAbsolute();

   public long lastModified() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkRead(this.path);
      }

      return this.lastModified0();
   }

   public long length() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkRead(this.path);
      }

      return this.length0();
   }

   public boolean mkdir() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkWrite(this.path);
      }

      return this.mkdir0();
   }

   public boolean renameTo(File var1) {
      SecurityManager var2 = System.getSecurityManager();
      if (var2 != null) {
         var2.checkWrite(this.path);
         var2.checkWrite(var1.path);
      }

      return this.renameTo0(var1);
   }

   public boolean mkdirs() {
      if (this.exists()) {
         return false;
      } else if (this.mkdir()) {
         return true;
      } else {
         String var1 = this.getParent();
         return var1 != null && (new File(var1)).mkdirs() && this.mkdir();
      }
   }

   public String[] list() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkRead(this.path);
      }

      return this.list0();
   }

   public String[] list(FilenameFilter var1) {
      String[] var2 = this.list();
      if (var2 == null) {
         return null;
      } else {
         Vector var3 = new Vector();

         for(int var4 = 0; var4 < var2.length; ++var4) {
            if (var1 == null || var1.accept(this, var2[var4])) {
               var3.addElement(var2[var4]);
            }
         }

         String[] var5 = new String[var3.size()];
         var3.copyInto(var5);
         return var5;
      }
   }

   public boolean delete() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkDelete(this.path);
      }

      SecurityManager.enablePrivilege("UniversalFileRead");
      return this.isDirectory() ? this.rmdir0() : this.delete0();
   }

   public int hashCode() {
      return this.path.hashCode() ^ 1234321;
   }

   public boolean equals(Object var1) {
      return var1 != null && var1 instanceof File ? this.path.equals(((File)var1).path) : false;
   }

   public String toString() {
      return this.getPath();
   }

   private synchronized void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      var1.writeChar(separatorChar);
   }

   private synchronized void readObject(ObjectInputStream var1) throws IOException, ClassNotFoundException {
      var1.defaultReadObject();
      char var2 = var1.readChar();
      if (var2 != separatorChar) {
         this.path = this.path.replace(var2, separatorChar);
      }

   }

   public long lastAccessed() {
      System.getSecurityManager().checkRead(this.path);
      return this.lastAccessed0();
   }

   public long lastStatusChange() {
      System.getSecurityManager().checkRead(this.path);
      return this.lastStatusChange0();
   }

   public boolean isLink() {
      System.getSecurityManager().checkRead(this.path);
      return this.isLink0();
   }

   private native long lastAccessed0();

   private native long lastStatusChange0();

   private native boolean isLink0();

   static {
      separatorChar = separator.charAt(0);
      pathSeparator = System.getProperty("path.separator");
      pathSeparatorChar = pathSeparator.charAt(0);
   }
}
